Returns the path to a GeoTIFF bundled with the package. Useful when
you want to read the raster with another tool (e.g. stars, GDAL,
rayshader) instead of terra.
Usage
nyc_terrain_path(resolution = c("100ft", "50ft"))Returns the path to a GeoTIFF bundled with the package. Useful when
you want to read the raster with another tool (e.g. stars, GDAL,
rayshader) instead of terra.
nyc_terrain_path(resolution = c("100ft", "50ft"))